@@ -7,20 +7,21 @@ import re
 import xml.etree.ElementTree as ET
 from IPython.display import HTML, display
 
-
 # WebNLG: https://gitlab.com/shimorina/webnlg-dataset.git
 # DART: https://github.com/Yale-LILY/dart.git
 
 files = []
-dirc = ['/webnlg-dataset/release_v2.1/xml/train/**/*.xml',
-        '/webnlg-dataset/release_v3.0/en/train/**/*.xml',
-        '/webnlg-dataset/webnlg_challenge_2017/train/**/*.xml',
-        '/dart/data/v1.1.1/dart-v1.1.1-full-train.xml']
+dirc = [
+    "/webnlg-dataset/release_v2.1/xml/train/**/*.xml",
+    "/webnlg-dataset/release_v3.0/en/train/**/*.xml",
+    "/webnlg-dataset/webnlg_challenge_2017/train/**/*.xml",
+    "/dart/data/v1.1.1/dart-v1.1.1-full-train.xml",
+]
 for dir in dirc:
     file = glob.glob("{}".format(dir), recursive=True)
     files.append(file)
 
-triple_re = re.compile('(\d)triples')
+triple_re = re.compile("(\d)triples")
 data_dct = {}
 for file in files:
     tree = ET.parse(file)
@@ -34,21 +35,23 @@ for file in files:
                 unstructured.append(entry.text)
                 strutured = [triple.text for triple in entry]
                 strutured_master.extend(strutured)
-            unstructured = [i for i in unstructured if i.replace('\n', '').strip() != '']
+            unstructured = [
+                i for i in unstructured if i.replace("\n", "").strip() != ""
+            ]
             strutured_master = strutured_master[-triples_num:]
-            strutured_master_str = (' && ').join(strutured_master)
+            strutured_master_str = (" && ").join(strutured_master)
             data_dct[strutured_master_str] = unstructured
     print(file)
 mdata_dct = {"prefix": [], "input_text": [], "target_text": []}
 for st, unst in data_dct.items():
     for i in unst:
-        mdata_dct['prefix'].append('webNLG')
-        mdata_dct['input_text'].append(st)
-        mdata_dct['target_text'].append(i)
+        mdata_dct["prefix"].append("webNLG")
+        mdata_dct["input_text"].append(st)
+        mdata_dct["target_text"].append(i)
 
 df1 = pd.DataFrame(mdata_dct)
 
-train_df = pd.read_csv('NLGDataset.csv', index_col=[0])
+train_df = pd.read_csv("NLGDataset.csv", index_col=[0])
 train_df = train_df.iloc[:73424, :]
 train_df = train_df.sample(frac=1)
 batch_size = 8
@@ -63,29 +66,34 @@ else:
 
 
 def progress(loss, value, max=100):
-    return HTML(""" Batch loss :{loss}
+    return HTML(
+        """ Batch loss :{loss}
       <progress    
 value='{value}'max='{max}',style='width: 100%'>{value}
       </progress>
-             """.format(loss=loss, value=value, max=max))
+             """.format(
+            loss=loss, value=value, max=max
+        )
+    )
 
 
-tokenizer = T5Tokenizer.from_pretrained('t5-base')
-model = T5ForConditionalGeneration.from_pretrained('t5-base',
-                                                   return_dict=True)
+tokenizer = T5Tokenizer.from_pretrained("t5-base")
+model = T5ForConditionalGeneration.from_pretrained("t5-base", return_dict=True)
 # moving the model to GPU
 model.to(dev)
 
-optimizer = Adafactor(model.parameters(),
-                      lr=1e-3,
-                      eps=(1e-30, 1e-3),
-                      clip_threshold=1.0,
-                      decay_rate=-0.8,
-                      beta1=None,
-                      weight_decay=0.0,
-                      relative_step=False,
-                      scale_parameter=False,
-                      warmup_init=False)
+optimizer = Adafactor(
+    model.parameters(),
+    lr=1e-3,
+    eps=(1e-30, 1e-3),
+    clip_threshold=1.0,
+    decay_rate=-0.8,
+    beta1=None,
+    weight_decay=0.0,
+    relative_step=False,
+    scale_parameter=False,
+    warmup_init=False,
+)
 
 
 def trainer(num_of_epochs):
@@ -93,7 +101,7 @@ def trainer(num_of_epochs):
 
     loss_per_10_steps = []
     for epoch in range(1, num_of_epochs + 1):
-        print('Running epoch: {}'.format(epoch))
+        print("Running epoch: {}".format(epoch))
 
         running_loss = 0
 
@@ -103,16 +111,18 @@ def trainer(num_of_epochs):
         for i in range(num_of_batches):
             inputbatch = []
             labelbatch = []
-            new_df = train_df[i * batch_size:i * batch_size + batch_size]
+            new_df = train_df[i * batch_size : i * batch_size + batch_size]
             for indx, row in new_df.iterrows():
-                input = row['input_text'] + '</s>'
-                labels = row['target_text'] + '</s>'
+                input = row["input_text"] + "</s>"
+                labels = row["target_text"] + "</s>"
                 inputbatch.append(input)
                 labelbatch.append(labels)
-            inputbatch = tokenizer.batch_encode_plus(inputbatch, padding=True, max_length=400, return_tensors='pt')[
-                "input_ids"]
-            labelbatch = tokenizer.batch_encode_plus(labelbatch, padding=True, max_length=400, return_tensors="pt")[
-                "input_ids"]
+            inputbatch = tokenizer.batch_encode_plus(
+                inputbatch, padding=True, max_length=400, return_tensors="pt"
+            )["input_ids"]
+            labelbatch = tokenizer.batch_encode_plus(
+                labelbatch, padding=True, max_length=400, return_tensors="pt"
+            )["input_ids"]
             inputbatch = inputbatch.to(dev)
             labelbatch = labelbatch.to(dev)
 
@@ -137,5 +147,5 @@ def trainer(num_of_epochs):
 
         running_loss = running_loss / int(num_of_batches)
         evaluation_total = time.time() - evaluation_start
-        print('Training time:', evaluation_total)
-        print('Epoch: {} , Running loss: {}'.format(epoch, running_loss))
+        print("Training time:", evaluation_total)
+        print("Epoch: {} , Running loss: {}".format(epoch, running_loss))
